@@ -129,6 +129,16 @@ class ArchiveDetail(LoginRequiredMixin, generic.DetailView):
         return get_object_or_404(Archive, owner=self.request.user, id_owner=self.kwargs['id_owner'])
 
 
+@method_decorator(cache_control(private=True), name='dispatch')
+class ArchivePrint(LoginRequiredMixin, generic.DetailView):
+    model = Archive
+    template_name = 'schema/archive_print.html'
+
+    # Restrict to objects we own
+    def get_object(self):
+        return get_object_or_404(Archive, owner=self.request.user, id_owner=self.kwargs['id_owner'])
+
+
 class ArchiveCreate(LoginRequiredMixin, CreateView):
     model = Archive
     form_class = ArchiveForm
@@ -938,6 +948,16 @@ class PrintDetail(LoginRequiredMixin, generic.DetailView):
         return get_object_or_404(Print, owner=self.request.user, id_owner=self.kwargs['id_owner'])
 
 
+@method_decorator(cache_control(private=True), name='dispatch')
+class PrintPrint(LoginRequiredMixin, generic.DetailView):
+    model = Print
+    template_name = 'schema/print_print.html'
+
+    # Restrict to objects we own
+    def get_object(self):
+        return get_object_or_404(Print, owner=self.request.user, id_owner=self.kwargs['id_owner'])
+
+
 class PrintCreate(LoginRequiredMixin, CreateView):
     model = Print
     form_class = PrintForm
@@ -1085,6 +1105,16 @@ class FilmDetail(LoginRequiredMixin, generic.DetailView):
         return get_object_or_404(Film, owner=self.request.user, id_owner=self.kwargs['id_owner'])
 
 
+@method_decorator(cache_control(private=True), name='dispatch')
+class FilmPrint(LoginRequiredMixin, generic.DetailView):
+    model = Film
+    template_name = 'schema/film_print.html'
+
+    # Restrict to objects we own
+    def get_object(self):
+        return get_object_or_404(Film, owner=self.request.user, id_owner=self.kwargs['id_owner'])
+
+
 class FilmCreate(LoginRequiredMixin, CreateView):
     model = Film
     form_class = FilmAddForm
